@@ -2,7 +2,8 @@
  * AT-SPI - Assistive Technology Service Provider Interface
  * (Gnome Accessibility Project; http://developer.gnome.org/projects/gap)
  *
- * Copyright 2001 Sun Microsystems Inc.
+ * Copyright 2001, 2002 Sun Microsystems Inc.,
+ * Copyright 2001, 2002 Ximian, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -26,8 +27,8 @@
 #include <bonobo-activation/bonobo-activation.h>
 #include <atk/atkobject.h>
 #include <libspi/Accessibility.h>
-#include "accessible.h"
-#include "application.h"
+#include <libspi/accessible.h>
+#include <libspi/application.h>
 
 #define APP_STATIC_BUFF_SZ 30
 
